Official XPay Bindings for Python
===================================

A Python library for XPay's API.


Setup
-----

You can install this package by using the pip tool and installing:

    $ pip install xpay

Or:

    $ easy_install xpay


Setting up a XPay Account
---------------------------

Sign up for XPay at https://dashboard.xpay.com/register.

Using the XPay API
--------------------

Documentation for the python bindings can be found alongside XPay's other bindings here:

- https://xpay.com/docs
- https://xpay.com/docs/api/?lang=python

In the standard documentation (the first link), most of the reference pages will have examples in XPay's official bindings (including Python). Just click on the Python tab to get the relevant documentation.

In the full API reference for python (the second link), the right half of the page will provide example requests and responses for various API calls.
